@@ -11,7 +11,7 @@ use base qw( IO::Async::Stream );
 
 use Carp;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use Protocol::WebSocket::Frame;
 
@@ -102,7 +102,9 @@ L<Future> instances.
 
 =cut
 
-=head2 $self->send_frame( @args )->get
+=head2 send_frame
+
+   $self->send_frame( @args )->get
 
 Sends a frame to the peer containing containing the given string. The
 arguments are passed to L<Protocol::WebSocket::Frame>'s C<new> method.
